@@ -1,13 +1,10 @@
 package Date::Holidays;
 
-# $Id: Holidays.pm 1820 2007-03-13 20:03:02Z jonasbn $
-
 use strict;
 use warnings;
 use vars qw($VERSION);
 use Locale::Country qw(all_country_codes code2country);
 use Module::Load qw(load);
-use UNIVERSAL qw(can);
 use Carp;
 use DateTime;
 use Error qw(:try);
@@ -21,7 +18,7 @@ use Date::Holidays::Exception::UnsupportedMethod;
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '0.18';
+$VERSION = '0.19';
 
 sub new {
     my ( $class, %params ) = @_;
@@ -45,7 +42,7 @@ sub new {
         catch Date::Holidays::Exception::SuperAdapterLoad with {
             $self = undef;
         };
-        
+
     } else {
         throw Date::Holidays::Exception::NoCountrySpecified(
             "No country code specified");
@@ -73,7 +70,7 @@ sub new {
         catch Date::Holidays::Exception::AdapterInitialization with {
             $self = undef;
         };
-        
+
     } elsif ( !$self->{'_inner_class'} ) {
         $self = undef;
     }
@@ -125,9 +122,9 @@ sub is_holiday {
 
         if ( not $params{'countries'} ) {
             my @countries = all_country_codes();    #from Locale::Country
-            
+
             @countries = sort @countries;
-            
+
             $params{'countries'} = \@countries;
         }
         $r = __PACKAGE__->_check_countries(%params);
@@ -263,10 +260,24 @@ sub _fetch {
 
 __END__
 
+=pod
+
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Date-Holidays.svg)](http://badge.fury.io/pl/Date-Holidays)
+[![Build Status](https://travis-ci.org/jonasbn/Date-Holidays.svg?branch=master)](https://travis-ci.org/jonasbn/Date-Holidays)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/Date-Holidays/badge.png?branch=master)](https://coveralls.io/r/jonasbn/Date-Holidays?branch=master)
+
+=end markdown
+
 =head1 NAME
 
 Date::Holidays - a Date::Holidays::* OOP Adapter aggregator
 
+=head1 VERSION
+
+This POD describes version 0.19 of Date::Holidays
+
 =head1 SYNOPSIS
 
 	use Date::Holidays;
@@ -285,7 +296,7 @@ Date::Holidays - a Date::Holidays::* OOP Adapter aggregator
 		year => 2004
 	);
 
-	
+
 	$holidays_hashref = Date::Holidays->is_holiday(
 		year      => 2004,
 		month     => 12,
@@ -303,8 +314,8 @@ Date::Holidays - a Date::Holidays::* OOP Adapter aggregator
 		month     => 12,
 		day       => 25,
 	);
-	
-	
+
+
 	#Example of a module with additional parameters
 	my $dh = Date::Holidays->new(
 		countrycode => 'au'
@@ -315,17 +326,13 @@ Date::Holidays - a Date::Holidays::* OOP Adapter aggregator
 		month => 12,
 		day   => 25,
 		state => 'TAS',
-	);	
+	);
 
 	$hashref = $dh->holidays(
 		year => 2004
 		state => 'TAS',
 	);
 
-=head1 VERSION
-
-This POD describes version 0.15 of Date::Holidays
-
 =head1 DESCRIPTION
 
 Date::Holidays is an aggregator of adapters exposing a uniform API to a set of
@@ -356,7 +363,7 @@ This is the constructor. It takes the following parameters:
 
 =over
 
-=item countrycode (MANDATORY, see below), two letter unique code representing a 
+=item countrycode (MANDATORY, see below), two letter unique code representing a
 country name.  Please refer to ISO3166 (or L<Locale::Country>)
 
 =item nocheck (optional), if set to true the countrycode specified will not be
@@ -365,7 +372,7 @@ fake countries, I currently use this for test.
 
 =back
 
-The constructor loads the module from Date::Holidays::*, which matches the 
+The constructor loads the module from Date::Holidays::*, which matches the
 country code and returns a Date::Holidays module with the specified module
 loaded and ready to answer to any of the following methods described below, if
 these are implemented - of course.
@@ -418,7 +425,7 @@ Takes 3 named arguments:
 
 =back
 
-is_holiday returns the name of a holiday is present in the country specified by 
+is_holiday returns the name of a holiday is present in the country specified by
 the country code provided to the Date::Holidays constructor.
 
 	$name = $dh->is_holiday(year => 2007, day => 24, month => 12);
@@ -493,10 +500,10 @@ scalar in the national language of the module context in question. Returns
 undef if the requested day is not a holiday.
 
 	Modified example taken from: L<Date::Holidays::DK>
-	
+
 	use Date::Holidays::DK;
     my ($year, $month, $day) = (localtime)[ 5, 4, 3 ];
-    
+
 	$year  += 1900;
     $month += 1;
     print "Woohoo" if is_holiday( $year, $month, $day );
@@ -526,7 +533,7 @@ The keys are the dates, month + day in two digits each concatenated.
 
 	#The actual method might not be implemented at this time in the
 	#example module.
-		
+
 =item <countrycode>_holidays
 
 This method however should be a wrapper of the above method (or the other way
@@ -542,22 +549,22 @@ L<Date::Holidays::Super> and are required by L<Date::Holidays::Abstract>.
 Some countries are divided into regions or similar and might require additional
 parameters in order to give more exact holiday data.
 
-This is handled by adding additional parameters to B<is_holiday> and 
+This is handled by adding additional parameters to B<is_holiday> and
 B<holidays>.
 
 These parameters are left to the module authors descretion and the actual
 Date::Holidays::* module should be consulted.
 
 	Example Date::Holidays::AU
-	
+
     use Date::Holidays::AU qw( is_holiday );
-    
+
 	my ($year, $month, $day) = (localtime)[ 5, 4, 3 ];
     $year  += 1900;
     $month += 1;
-    
+
 	my ($state) = 'VIC';
-    print "Excellent\n" if is_holiday( $year, $month, $day, $state );	
+    print "Excellent\n" if is_holiday( $year, $month, $day, $state );
 
 =head1 DEVELOPING A DATE::HOLIDAYS::ADAPTER CLASS
 
@@ -621,8 +628,6 @@ No special configuration or environment is required.
 
 =item * L<Error>
 
-=item * L<UNIVERSAL>
-
 =item * L<Date::Holidays::Adapter>
 
 =back
@@ -634,7 +639,7 @@ specific adapter classes or their respective adaptees.
 
 =head1 BUGS AND LIMITATIONS
 
-Currently we have an exception for the L<Date::Holidays::AU> module, so the 
+Currently we have an exception for the L<Date::Holidays::AU> module, so the
 additional parameter of state is defaulting to 'VIC', please refer to the POD
 for L<Date::Holidays::AU> for documentation on this.
 
@@ -770,7 +775,7 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 =head1 LICENSE AND COPYRIGHT
 
 Date-Holidays and related modules are (C) by Jonas B. Nielsen, (jonasbn)
-2004-2007
+2004-2014
 
 Date-Holidays and related modules are released under the artistic license
 
